summaryrefslogtreecommitdiffstats
path: root/kcron
diff options
context:
space:
mode:
Diffstat (limited to 'kcron')
-rw-r--r--kcron/ctcron.cpp4
-rw-r--r--kcron/ktapp.cpp2
-rw-r--r--kcron/ktapp.h4
-rw-r--r--kcron/ktlisttasks.cpp2
-rw-r--r--kcron/ktlistvars.cpp2
-rw-r--r--kcron/ktprint.cpp6
-rw-r--r--kcron/ktprint.h2
-rw-r--r--kcron/ktview.cpp8
8 files changed, 15 insertions, 15 deletions
diff --git a/kcron/ctcron.cpp b/kcron/ctcron.cpp
index 58d389a..e470a72 100644
--- a/kcron/ctcron.cpp
+++ b/kcron/ctcron.cpp
@@ -60,7 +60,7 @@ CTCron::CTCron(bool _syscron, string _login) :
writeCommand = TQString("crontab -u ") + _login.c_str() + " " + KProcess::quote(tmpFileName);
if (!initFromPasswd(getpwnam(_login.c_str())))
{
- error = i18n("No password entry found for user '%1'").tqarg(_login.c_str());
+ error = i18n("No password entry found for user '%1'").arg(_login.c_str());
}
}
}
@@ -71,7 +71,7 @@ CTCron::CTCron(bool _syscron, string _login) :
writeCommand = "crontab " + KProcess::quote(tmpFileName);
if (!initFromPasswd(getpwuid(uid)))
{
- error = i18n("No password entry found for uid '%1'").tqarg(uid);
+ error = i18n("No password entry found for uid '%1'").arg(uid);
}
}
diff --git a/kcron/ktapp.cpp b/kcron/ktapp.cpp
index dfbe15e..8efbb05 100644
--- a/kcron/ktapp.cpp
+++ b/kcron/ktapp.cpp
@@ -70,7 +70,7 @@ bool KTApp::init()
if (cthost->isError())
{
KMessageBox::error(this, i18n("The following error occurred while initializing KCron:"
- "\n\n%1\n\nKCron will now exit.\n").tqarg(cthost->errorMessage()));
+ "\n\n%1\n\nKCron will now exit.\n").arg(cthost->errorMessage()));
return false;
}
diff --git a/kcron/ktapp.h b/kcron/ktapp.h
index 6b28354..a60c7ca 100644
--- a/kcron/ktapp.h
+++ b/kcron/ktapp.h
@@ -238,13 +238,13 @@ private:
/**
* Read general options again and initialize all variables like the
- * tqgeometry.
+ * geometry.
*/
void readOptions();
/**
* Save general options like all bar positions and status as well as the
- * tqgeometry to the configuration file.
+ * geometry to the configuration file.
*/
void saveOptions();
diff --git a/kcron/ktlisttasks.cpp b/kcron/ktlisttasks.cpp
index db153e6..e35f053 100644
--- a/kcron/ktlisttasks.cpp
+++ b/kcron/ktlisttasks.cpp
@@ -77,7 +77,7 @@ void KTListTasks::print (KTPrint& printer) const
printer.setFont(stnd);
- //firstChild() does not return null if there are no tqchildren, therefore
+ //firstChild() does not return null if there are no children, therefore
//we need to check the validation of the pointer without terminating
//the application. This maybe a bug in QT 1.44
diff --git a/kcron/ktlistvars.cpp b/kcron/ktlistvars.cpp
index 567d3d1..cf4a6d1 100644
--- a/kcron/ktlistvars.cpp
+++ b/kcron/ktlistvars.cpp
@@ -73,7 +73,7 @@ void KTListVars::print(KTPrint& printer) const
printer.setFont(stnd);
- //firstChild() does not return null if there are no tqchildren, therefore
+ //firstChild() does not return null if there are no children, therefore
//we need to check the validation of the pointer without terminating
//the application. This maybe a bug in QT 1.44
diff --git a/kcron/ktprint.h b/kcron/ktprint.h
index 34b0254..b035626 100644
--- a/kcron/ktprint.h
+++ b/kcron/ktprint.h
@@ -87,7 +87,7 @@ public:
/**
* Print text
*/
- void print (const TQString &str, int col =1, int tqalignment=KTPrint::defaultLeftMargin, bool wordWrap = true);
+ void print (const TQString &str, int col =1, int alignment=KTPrint::defaultLeftMargin, bool wordWrap = true);
/**
* Constructs the columns
diff --git a/kcron/ktview.cpp b/kcron/ktview.cpp
index af2b780..27341de 100644
--- a/kcron/ktview.cpp
+++ b/kcron/ktview.cpp
@@ -273,9 +273,9 @@ void KTView :: pageHeading (KTListItem* user, KTPrint &printer) const
// SSA : Fix Me user name, logon name and host name musst be
// SSA : not only in us-ascii ??
logonInfo = i18n("user on host", "%1 <%2> on %3")
- .tqarg(TQString::fromLocal8Bit(user->getCTCron()->name.c_str()))
- .tqarg(TQString::fromLocal8Bit(user->getCTCron()->login.c_str()))
- .tqarg(TQString::fromLocal8Bit(hostName));
+ .arg(TQString::fromLocal8Bit(user->getCTCron()->name.c_str()))
+ .arg(TQString::fromLocal8Bit(user->getCTCron()->login.c_str()))
+ .arg(TQString::fromLocal8Bit(hostName));
stnd = printer.getFont();
printer.setFont(TQFont( KGlobalSettings::generalFont().family(), 14, TQFont::Bold ));
@@ -315,7 +315,7 @@ void KTView::resizeEvent (TQResizeEvent*)
{
listView->setFixedWidth(width());
listView->setFixedHeight(height());
- tqrepaint();
+ repaint();
}
void KTView::copy()
diff --git a/kcron/ktprint.cpp b/kcron/ktprint.cpp
index ceb1482..b1de5c6 100644
--- a/kcron/ktprint.cpp
+++ b/kcron/ktprint.cpp
@@ -104,7 +104,7 @@ TQFont KTPrint :: getFont () const
return paint->font();
}
-void KTPrint :: print (const TQString &str, int col, int tqalignment, bool wordWrap)
+void KTPrint :: print (const TQString &str, int col, int alignment, bool wordWrap)
{
//Prints the string str into the column col using
//the remaining arguments as format flags
@@ -115,8 +115,8 @@ void KTPrint :: print (const TQString &str, int col, int tqalignment, bool wordW
return;
- //Setup the tqalignment
- switch (tqalignment) {
+ //Setup the alignment
+ switch (alignment) {
case alignTextLeft : format = AlignLeft | AlignTop | DontClip | ExpandTabs; break;
case alignTextCenter : format = AlignHCenter | AlignTop | DontClip | ExpandTabs; break;
case alignTextRight : format = AlignRight | AlignTop | DontClip | ExpandTabs; break;